..
  SPDX-FileCopyrightText: 2025 Ilya Egorov <0x42005e1f@gmail.com>
  SPDX-License-Identifier: CC-BY-4.0

=======
culsans
=======

.. include:: ../README.rst
  :start-after: .. description-start-marker
  :end-before: .. description-end-marker

Usage
=====

.. include:: ../README.rst
  :start-after: .. usage-start-marker
  :end-before: .. usage-end-marker

Compatibility
=============

.. include:: ../README.rst
  :start-after: .. compatibility-start-marker
  :end-before: .. compatibility-end-marker

.. toctree::
  :maxdepth: 2
  :hidden:

  api

.. toctree::
  :caption: Quickstart
  :maxdepth: 3
  :hidden:

  installation

.. toctree::
  :caption: Meta
  :maxdepth: 1
  :hidden:

  changelog
  license

.. toctree::
  :caption: Links
  :hidden:

  DeepWiki <https://deepwiki.com/x42005e1f/culsans>
  GitHub <https://github.com/x42005e1f/culsans>
  PyPI <https://pypi.org/project/culsans/>
